package org.rcisoft.app.appOrder.controller;


/*固定导入*/


import io.swagger.v3.oas.annotations.Operation;
import org.rcisoft.business.cmsOrder.entity.CmsOrder;
import org.rcisoft.business.cmsOrder.service.CmsOrderService;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;
import javax.validation.Valid;

/**
* Created by cy on 2024年12月20日 下午3:35:34.
*/
@RestController
@RequestMapping("/app")
public class AppOrderController extends CyPaginationController<CmsOrder> {

    @Autowired
    private CmsOrderService cmsOrderServiceImpl;

    @PreAuthorize("@cyPerm.hasPerm('app:order:add')")
    @CyOpeLogAnno(title = "system-订单信息表管理-活动下单", businessType = CyLogTypeEnum.INSERT)
    @Operation(summary="活动下单", description="活动下单")
    @PostMapping(value = "/order/add")
    public CyResult add(@Valid @RequestBody CmsOrder cmsOrder, BindingResult bindingResult) {
        CyPersistModel data = cmsOrderServiceImpl.persist(cmsOrder);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cmsOrder);
    }

    @PreAuthorize("@cyPerm.hasPerm('app:order:update')")
    @CyOpeLogAnno(title = "system-订单管理-活动取消", businessType = CyLogTypeEnum.UPDATE)
    @Operation(summary = "活动取消", description = "活动取消")
    @PostMapping(value = "/order/cancel")
    public CyResult cancel(@RequestBody CmsOrder orderInfo) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cmsOrderServiceImpl.cancel(orderInfo));
    }

    @PreAuthorize("@cyPerm.hasPerm('app:order:query')")
    @Operation(summary="查询会员我的订单列表", description="查询会员我的订单列表")
    @GetMapping("/order/selectOrderUserByPagination")
    public CyGridModel selectOrderUserByPagination(CmsOrder orderInfo)
    {
        cmsOrderServiceImpl.selectOrderUserByPagination(getPaginationUtility(), orderInfo);
        return getGridModelResponse();
    }


    @PreAuthorize("@cyPerm.hasPerm('app:order:add')")
    @CyOpeLogAnno(title = "system-订单信息表管理-充值金币", businessType = CyLogTypeEnum.INSERT)
    @Operation(summary="充值金币", description="充值金币")
    @PostMapping(value = "/order/addGold")
    public CyResult addGold(@Valid @RequestBody CmsOrder cmsOrder, BindingResult bindingResult) {
        CmsOrder data = cmsOrderServiceImpl.addGold(cmsOrder);
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                data);
    }
}
